@@ -7,7 +7,6 @@ if (!isset($_SESSION['userid']))
     die();
 }
 
-
 $project = (object) new project();
 
 $action = getArrayVal($_GET, "action");
@@ -114,7 +113,6 @@ if ($action == "editform")
         }
         else
         {
-            // header("Location: myprojects.php");
             echo "ok";
         }
     }
@@ -156,7 +154,6 @@ if ($action == "editform")
     if ($project->close($id))
     {
         echo "ok";
-        // header("Location: index.php");
     }
     else
     {
@@ -183,7 +180,7 @@ if ($action == "editform")
             {
                 // send email
                 $themail = new emailer($settings);
-                $themail->send_mail($user["email"], $langfile["projectassignedsubject"] , $langfile["projectassignedtext"] . " <a href = \"" . $url . "manageproject.php?action=showproject&id=$id\">" . $url . "manageproject.php?action=showproject&id=$id</a>");
+                $themail->send_mail($user["email"], $langfile["projectassignedsubject"] , $langfile["hello"] . ",<br /><br/>" . $langfile["projectassignedtext"] . " <a href = \"" . $url . "manageproject.php?action=showproject&id=$id\">" . $url . "manageproject.php?action=showproject&id=$id</a>");
             }
         }
         if ($redir)
@@ -342,7 +339,7 @@ if ($action == "editform")
             {
                 $icon = "templates/standard/images/symbols/tasklist.png";
             }
-            // $icon = utf8_decode($langfile[$logged["type"]]);
+            
             if ($logged["action"] == 1)
             {
                 $actstr = $langfile["added"];
@@ -527,7 +524,7 @@ if ($action == "editform")
     $headstr = utf8_decode($headstr);
     $pdf->FancyTable($headline, $datlog, 9, $headstr);
     $pdf->SetFont('Arial', '', 14);
-    // diagramm
+    // Chart
     $data = array($stropen => $open, $strdone => $done);
     $pdf->SetXY(100, 20);
     $col1 = array(255, 0, 0);
@@ -729,4 +726,3 @@ if ($action == "editform")
     $template->assign("id", $id);
     $template->display("calbody_project.tpl");
 }
-
